/*
Copyright © 2022 Volodymyr Patuta me@vpatuta.xyz

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"strconv"
	"strings"

	"github.com/spf13/cobra"
)

// edCmd represents the ed command
var edCmd = &cobra.Command{
	Use:   "ed [id]",
	Short: "Edit a todo",
	Long: `Edit a todo giving an ID as arg1, then all args are
taken as a string.

You can edit a due date with '-d DATE'.
You can mark a todo as completed with '-c'.
`,
	Args: func(cmd *cobra.Command, args []string) error {
		if cmd.Flags().NFlag() >= 1 {
			if err := cobra.MinimumNArgs(1)(cmd, args); err != nil {
				return err
			}

			return nil
		}
		if err := cobra.MinimumNArgs(2)(cmd, args); err != nil {
			return err
		}

		return nil
	},
	Run: func(cmd *cobra.Command, args []string) {
		dateString, err := cmd.Flags().GetString("due")
		errPanic(err, "")
		comp, err := cmd.Flags().GetBool("complete")
		errPanic(err, "")
		id, err := strconv.ParseUint(args[0], 10, 0)
		errPanic(err, "failed to parse uint")
		updateTodo(id, strings.Join(args[1:], " "), dateString, comp)
	},
}

func init() {
	rootCmd.AddCommand(edCmd)

	edCmd.Flags().StringP("due", "d", "", "due date")
	edCmd.Flags().BoolP("complete", "c", false, "toggle task as completed/uncompleted")
}
