/*
Copyright © 2022 Volodymyr Patuta me@vpatuta.xyz

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"os"

	"github.com/spf13/cobra"
)

// rootCmd represents the base command when called without any subcommands
var rootCmd = &cobra.Command{
	Use:   "todo",
	Short: "Minimal todo app",
	Long: `Minimal todo app which lets you create,
remove, edit and list your todos.

You can optionally add due date and mark todo as completed.
Running without flags lists all uncompleted todos.`,
	Run: lsCmd.Run,
}

// Execute adds all child commands to the root command and sets flags appropriately.
// This is called by main.main(). It only needs to happen once to the rootCmd.
func Execute() {
	err := rootCmd.Execute()
	if err != nil {
		os.Exit(1)
	}
}

func init() {
	rootCmd.Flags().BoolP("all", "a", false, "show all todos")
	rootCmd.Flags().BoolP("completed", "c", false, "show all completed todos")
	rootCmd.Flags().BoolP("verbose", "v", false, "show all fields of todos")
}
